@@ -6,7 +6,7 @@ from pathlib import Path
 import pytest
 from typer.testing import CliRunner
 
-from docs_src.exceptions import tutorial002 as mod
+from docs_src.exceptions import tutorial002_py39 as mod
 
 runner = CliRunner()
 
@@ -14,7 +14,7 @@ runner = CliRunner()
 def test_traceback_rich():
     file_path = Path(mod.__file__)
     result = subprocess.run(
-        [sys.executable, "-m", "coverage", "run", str(file_path), "secret"],
+        [sys.executable, "-m", "coverage", "run", str(file_path)],
         capture_output=True,
         encoding="utf-8",
         env={
@@ -26,9 +26,9 @@ def test_traceback_rich():
     assert "return get_command(self)(*args, **kwargs)" not in result.stderr
 
     assert "app()" not in result.stderr
-    assert "print(password + 3)" in result.stderr
+    assert "print(name + 3)" in result.stderr
     assert 'TypeError: can only concatenate str (not "int") to str' in result.stderr
-    assert "name = 'morty'" not in result.stderr
+    assert "name = 'morty'" in result.stderr
 
 
 @pytest.mark.parametrize(
@@ -37,7 +37,7 @@ def test_traceback_rich():
 def test_standard_traceback_env_var(env_var: str):
     file_path = Path(mod.__file__)
     result = subprocess.run(
-        [sys.executable, "-m", "coverage", "run", str(file_path), "secret"],
+        [sys.executable, "-m", "coverage", "run", str(file_path)],
         capture_output=True,
         encoding="utf-8",
         env={**os.environ, env_var: "1"},
@@ -45,7 +45,7 @@ def test_standard_traceback_env_var(env_var: str):
     assert "return get_command(self)(*args, **kwargs)" in result.stderr
 
     assert "app()" in result.stderr
-    assert "print(password + 3)" in result.stderr
+    assert "print(name + 3)" in result.stderr
     assert 'TypeError: can only concatenate str (not "int") to str' in result.stderr
     assert "name = 'morty'" not in result.stderr
 
